function [x] = gdexprnd(n, p, lam1, lam2)
% sample of size n from generalized double exponential distribution
% f(x) = p * f_1(x) + (1-p) * f_2(x)
% f_1(x) = lam1 * exp(lam1 * x), x<0
% f_2(x) = lam2 * exp(-lam2 * x), x >= 0

x = zeros(n, 1); % initialize vector of sampled values

for i = 1:n
    
    u = rand(2, 1); % generate 2 uniforms in (0,1)
    
    if u(1) < p % with probability p
        
        x(i) = 1 / lam1 * log(u(2)); % draw from first mixture component
        
    else % with probability 1 - p
        
        x(i) = -1 / lam2 * log(u(2)); % draw from second mixture component
        
    end


end
