function [x] = mixnorm(n, p, mu, var)
% Draw random sample of length n from Normal mixture
% f(x) = \sum_{i=1}^{length(p)} p_i * N(mu(i), var(i))
% mixture of length(p)-Normal components with corresponding mean and
% variance vectors mu, var
% mu, var, p must have the same length

x = zeros(n, 1); % initialize
psum = cumsum(p); % cumulative sum of mixing coefficients

for i = 1:n
    
    u = rand(1); % draw U(0,1)
    
    for j = 1:length(p) % draw from i-component with probability p_i
        
        if u <= psum(j)
            
            x(i) = normrnd(mu(j), sqrt(var(j)));
            
            break % break loop - component has been selected
            
        end
        
    end


end